@@ -1,4 +1,4 @@
-/*	$OpenBSD: config.c,v 1.99 2021/02/16 08:29:16 claudio Exp $ */
+/*	$OpenBSD: config.c,v 1.101 2022/02/23 11:20:35 claudio Exp $ */
 
 /*
  * Copyright (c) 2003, 2004, 2005 Henning Brauer <henning@openbsd.org>
@@ -31,7 +31,7 @@
 #include "session.h"
 #include "log.h"
 
-int		host_ip(const char *, struct bgpd_addr *, u_int8_t *);
+int		host_ip(const char *, struct bgpd_addr *, uint8_t *);
 void		free_networks(struct network_head *);
 
 struct bgpd_config *
@@ -356,11 +356,11 @@ merge_config(struct bgpd_config *xconf, struct bgpd_config *conf)
 	free_config(conf);
 }
 
-u_int32_t
+uint32_t
 get_bgpid(void)
 {
 	struct ifaddrs		*ifap, *ifa;
-	u_int32_t		 ip = 0, cur, localnet;
+	uint32_t		 ip = 0, cur, localnet;
 
 	localnet = htonl(INADDR_LOOPBACK & IN_CLASSA_NET);
 
@@ -383,7 +383,7 @@ get_bgpid(void)
 }
 
 int
-host(const char *s, struct bgpd_addr *h, u_int8_t *len)
+host(const char *s, struct bgpd_addr *h, uint8_t *len)
 {
 	int			 mask = 128;
 	char			*p, *ps;
@@ -417,7 +417,7 @@ host(const char *s, struct bgpd_addr *h, u_int8_t *len)
 }
 
 int
-host_ip(const char *s, struct bgpd_addr *h, u_int8_t *len)
+host_ip(const char *s, struct bgpd_addr *h, uint8_t *len)
 {
 	struct addrinfo		 hints, *res;
 	int			 bits;
@@ -447,30 +447,6 @@ prepare_listeners(struct bgpd_config *conf)
 	int			 opt = 1;
 	int			 r = 0;
 
-	if (TAILQ_EMPTY(conf->listen_addrs)) {
-		if ((la = calloc(1, sizeof(struct listen_addr))) == NULL)
-			fatal("setup_listeners calloc");
-		la->fd = -1;
-		la->flags = DEFAULT_LISTENER;
-		la->reconf = RECONF_REINIT;
-		la->sa_len = sizeof(struct sockaddr_in);
-		((struct sockaddr_in *)&la->sa)->sin_family = AF_INET;
-		((struct sockaddr_in *)&la->sa)->sin_addr.s_addr =
-		    htonl(INADDR_ANY);
-		((struct sockaddr_in *)&la->sa)->sin_port = htons(BGP_PORT);
-		TAILQ_INSERT_TAIL(conf->listen_addrs, la, entry);
-
-		if ((la = calloc(1, sizeof(struct listen_addr))) == NULL)
-			fatal("setup_listeners calloc");
-		la->fd = -1;
-		la->flags = DEFAULT_LISTENER;
-		la->reconf = RECONF_REINIT;
-		la->sa_len = sizeof(struct sockaddr_in6);
-		((struct sockaddr_in6 *)&la->sa)->sin6_family = AF_INET6;
-		((struct sockaddr_in6 *)&la->sa)->sin6_port = htons(BGP_PORT);
-		TAILQ_INSERT_TAIL(conf->listen_addrs, la, entry);
-	}
-
 	for (la = TAILQ_FIRST(conf->listen_addrs); la != NULL; la = next) {
 		next = TAILQ_NEXT(la, entry);
 		if (la->reconf != RECONF_REINIT)
