@@ -1,4 +1,4 @@
-/*	$OpenBSD: rde_rib.c,v 1.224 2021/08/09 08:15:35 claudio Exp $ */
+/*	$OpenBSD: rde_rib.c,v 1.237 2022/03/22 10:53:08 claudio Exp $ */
 
 /*
  * Copyright (c) 2003, 2004 Claudio Jeker <claudio@openbsd.org>
@@ -36,7 +36,7 @@
  * Therefore one thing needs to be absolutely avoided, long table walks.
  * This is achieved by heavily linking the different parts together.
  */
-u_int16_t rib_size;
+uint16_t rib_size;
 struct rib **ribs;
 
 struct rib_entry *rib_add(struct rib *, struct bgpd_addr *, int);
@@ -44,7 +44,7 @@ static inline int rib_compare(const struct rib_entry *,
 			const struct rib_entry *);
 void rib_remove(struct rib_entry *);
 int rib_empty(struct rib_entry *);
-static void rib_dump_abort(u_int16_t);
+static void rib_dump_abort(uint16_t);
 
 RB_PROTOTYPE(rib_tree, rib_entry, rib_e, rib_compare);
 RB_GENERATE(rib_tree, rib_entry, rib_e, rib_compare);
@@ -53,14 +53,14 @@ struct rib_context {
 	LIST_ENTRY(rib_context)		 entry;
 	struct rib_entry		*ctx_re;
 	struct prefix			*ctx_p;
-	u_int32_t			 ctx_id;
+	uint32_t			 ctx_id;
 	void		(*ctx_rib_call)(struct rib_entry *, void *);
 	void		(*ctx_prefix_call)(struct prefix *, void *);
-	void		(*ctx_done)(void *, u_int8_t);
+	void		(*ctx_done)(void *, uint8_t);
 	int		(*ctx_throttle)(void *);
 	void				*ctx_arg;
 	unsigned int			 ctx_count;
-	u_int8_t			 ctx_aid;
+	uint8_t				 ctx_aid;
 };
 LIST_HEAD(, rib_context) rib_dumps = LIST_HEAD_INITIALIZER(rib_dumps);
 
@@ -134,10 +134,10 @@ rib_compare(const struct rib_entry *a, const struct rib_entry *b)
 
 /* RIB specific functions */
 struct rib *
-rib_new(char *name, u_int rtableid, u_int16_t flags)
+rib_new(char *name, u_int rtableid, uint16_t flags)
 {
 	struct rib *new;
-	u_int16_t id;
+	uint16_t id;
 
 	for (id = 0; id < rib_size; id++) {
 		if (ribs[id] == NULL)
@@ -179,7 +179,7 @@ rib_new(char *name, u_int rtableid, u_int16_t flags)
  * or RECONF_REINIT (rerun the route decision process for every element)
  * depending on the new flags.
  */
-void
+int
 rib_update(struct rib *rib)
 {
 	/* flush fib first if there was one */
@@ -198,20 +198,22 @@ rib_update(struct rib *rib)
 	if (rib->fibstate != RECONF_REINIT &&
 	    (rib->flags & (F_RIB_NOFIB | F_RIB_NOEVALUATE)) == 0)
 		rib->fibstate = RECONF_RELOAD;
+
+	return (rib->fibstate == RECONF_REINIT);
 }
 
 struct rib *
-rib_byid(u_int16_t id)
+rib_byid(uint16_t id)
 {
 	if (id == RIB_NOTFOUND || id >= rib_size || ribs[id] == NULL)
 		return NULL;
 	return ribs[id];
 }
 
-u_int16_t
+uint16_t
 rib_find(char *name)
 {
-	u_int16_t id;
+	uint16_t id;
 
 	/* no name returns the first Loc-RIB */
 	if (name == NULL || *name == '\0')
@@ -250,7 +252,7 @@ rib_free(struct rib *rib)
 		 * an empty check in prefix_destroy() it is not possible to
 		 * use the default for loop.
 		 */
-		while ((p = LIST_FIRST(&re->prefix_h))) {
+		while ((p = TAILQ_FIRST(&re->prefix_h))) {
 			struct rde_aspath *asp = prefix_aspath(p);
 			if (asp && asp->pftableid)
 				rde_pftable_del(asp->pftableid, p);
@@ -269,7 +271,7 @@ void
 rib_shutdown(void)
 {
 	struct rib *rib;
-	u_int16_t id;
+	uint16_t id;
 
 	for (id = 0; id < rib_size; id++) {
 		rib = rib_byid(id);
@@ -297,11 +299,9 @@ struct rib_entry *
 rib_get(struct rib *rib, struct bgpd_addr *prefix, int prefixlen)
 {
 	struct rib_entry xre, *re;
-	struct pt_entry	*pte;
 
-	pte = pt_fill(prefix, prefixlen);
 	memset(&xre, 0, sizeof(xre));
-	xre.prefix = pte;
+	xre.prefix = pt_fill(prefix, prefixlen);
 
 	re = RB_FIND(rib_tree, rib_tree(rib), &xre);
 	if (re && re->rib_id != rib->id)
@@ -353,7 +353,7 @@ rib_add(struct rib *rib, struct bgpd_addr *prefix, int prefixlen)
 	if ((re = calloc(1, sizeof(*re))) == NULL)
 		fatal("rib_add");
 
-	LIST_INIT(&re->prefix_h);
+	TAILQ_INIT(&re->prefix_h);
 	re->prefix = pt_ref(pte);
 	re->rib_id = rib->id;
 
@@ -391,7 +391,7 @@ rib_remove(struct rib_entry *re)
 int
 rib_empty(struct rib_entry *re)
 {
-	return LIST_EMPTY(&re->prefix_h);
+	return TAILQ_EMPTY(&re->prefix_h);
 }
 
 static struct rib_entry *
@@ -481,7 +481,7 @@ rib_dump_runner(void)
 }
 
 static void
-rib_dump_abort(u_int16_t id)
+rib_dump_abort(uint16_t id)
 {
 	struct rib_context *ctx, *next;
 
@@ -519,8 +519,8 @@ rib_dump_terminate(void *arg)
 }
 
 int
-rib_dump_new(u_int16_t id, u_int8_t aid, unsigned int count, void *arg,
-    void (*upcall)(struct rib_entry *, void *), void (*done)(void *, u_int8_t),
+rib_dump_new(uint16_t id, uint8_t aid, unsigned int count, void *arg,
+    void (*upcall)(struct rib_entry *, void *), void (*done)(void *, uint8_t),
     int (*throttle)(void *))
 {
 	struct rib_context *ctx;
@@ -547,13 +547,13 @@ rib_dump_new(u_int16_t id, u_int8_t aid, unsigned int count, void *arg,
 /* path specific functions */
 
 static struct rde_aspath *path_lookup(struct rde_aspath *);
-static u_int64_t path_hash(struct rde_aspath *);
+static uint64_t path_hash(struct rde_aspath *);
 static void path_link(struct rde_aspath *);
 static void path_unlink(struct rde_aspath *);
 
 struct path_table {
 	struct aspath_head	*path_hashtbl;
-	u_int64_t		 path_hashmask;
+	uint64_t		 path_hashmask;
 } pathtable;
 
 SIPHASH_KEY pathtablekey;
@@ -585,9 +585,9 @@ path_unref(struct rde_aspath *asp)
 }
 
 void
-path_init(u_int32_t hashsize)
+path_init(uint32_t hashsize)
 {
-	u_int32_t	hs, i;
+	uint32_t	hs, i;
 
 	for (hs = 1; hs < hashsize; hs <<= 1)
 		;
@@ -605,7 +605,7 @@ path_init(u_int32_t hashsize)
 void
 path_shutdown(void)
 {
-	u_int32_t	i;
+	uint32_t	i;
 
 	for (i = 0; i <= pathtable.path_hashmask; i++)
 		if (!LIST_EMPTY(&pathtable.path_hashtbl[i]))
@@ -618,7 +618,7 @@ void
 path_hash_stats(struct rde_hashstats *hs)
 {
 	struct rde_aspath	*a;
-	u_int32_t		i;
+	uint32_t		i;
 	int64_t			n;
 
 	memset(hs, 0, sizeof(*hs));
@@ -688,11 +688,11 @@ path_compare(struct rde_aspath *a, struct rde_aspath *b)
 	return (attr_compare(a, b));
 }
 
-static u_int64_t
+static uint64_t
 path_hash(struct rde_aspath *asp)
 {
 	SIPHASH_CTX	ctx;
-	u_int64_t	hash;
+	uint64_t	hash;
 
 	SipHash24_Init(&ctx, &pathtablekey);
 	SipHash24_Update(&ctx, &asp->aspath_hashstart,
@@ -712,7 +712,7 @@ path_lookup(struct rde_aspath *aspath)
 {
 	struct aspath_head	*head;
 	struct rde_aspath	*asp;
-	u_int64_t		 hash;
+	uint64_t		 hash;
 
 	hash = path_hash(aspath);
 	head = PATH_HASH(hash);
@@ -842,30 +842,45 @@ path_put(struct rde_aspath *asp)
 /* prefix specific functions */
 
 static int	prefix_add(struct bgpd_addr *, int, struct rib *,
-		    struct rde_peer *, u_int32_t, struct rde_aspath *,
+		    struct rde_peer *, uint32_t, struct rde_aspath *,
 		    struct rde_community *, struct nexthop *,
-		    u_int8_t, u_int8_t);
+		    uint8_t, uint8_t);
 static int	prefix_move(struct prefix *, struct rde_peer *,
 		    struct rde_aspath *, struct rde_community *,
-		    struct nexthop *, u_int8_t, u_int8_t);
+		    struct nexthop *, uint8_t, uint8_t);
 
 static void	prefix_link(struct prefix *, struct rib_entry *,
-		     struct rde_peer *, u_int32_t, struct rde_aspath *,
-		     struct rde_community *, struct nexthop *,
-		     u_int8_t, u_int8_t);
+		     struct pt_entry *, struct rde_peer *, uint32_t,
+		     struct rde_aspath *, struct rde_community *,
+		     struct nexthop *, uint8_t, uint8_t);
 static void	prefix_unlink(struct prefix *);
 
 static struct prefix	*prefix_alloc(void);
 static void		 prefix_free(struct prefix *);
 
 /* RB tree comparison function */
+static inline int
+prefix_index_cmp(struct prefix *a, struct prefix *b)
+{
+	int r;
+	r = pt_prefix_cmp(a->pt, b->pt);
+	if (r != 0)
+		return r;
+
+	if (a->path_id_tx > b->path_id_tx)
+		return 1;
+	if (a->path_id_tx < b->path_id_tx)
+		return -1;
+	return 0;
+}
+
 static inline int
 prefix_cmp(struct prefix *a, struct prefix *b)
 {
-	if (a->eor != b->eor)
-		return a->eor - b->eor;
-	/* if EOR marker no need to check the rest also a->eor == b->eor */
-	if (a->eor)
+	if ((a->flags & PREFIX_FLAG_EOR) != (b->flags & PREFIX_FLAG_EOR))
+		return (a->flags & PREFIX_FLAG_EOR) ? 1 : -1;
+	/* if EOR marker no need to check the rest */
+	if (a->flags & PREFIX_FLAG_EOR)
 		return 0;
 
 	if (a->aspath != b->aspath)
@@ -876,25 +891,17 @@ prefix_cmp(struct prefix *a, struct prefix *b)
 		return (a->nexthop > b->nexthop ? 1 : -1);
 	if (a->nhflags != b->nhflags)
 		return (a->nhflags > b->nhflags ? 1 : -1);
-	/* XXX path_id ??? */
-	return pt_prefix_cmp(a->pt, b->pt);
-}
-
-static inline int
-prefix_index_cmp(struct prefix *a, struct prefix *b)
-{
-	/* XXX path_id ??? */
-	return pt_prefix_cmp(a->pt, b->pt);
+	return prefix_index_cmp(a, b);
 }
 
 RB_GENERATE(prefix_tree, prefix, entry.tree.update, prefix_cmp)
 RB_GENERATE_STATIC(prefix_index, prefix, entry.tree.index, prefix_index_cmp)
 
 /*
- * search for specified prefix of a peer. Returns NULL if not found.
+ * Search for specified prefix of a peer. Returns NULL if not found.
  */
 struct prefix *
-prefix_get(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
+prefix_get(struct rib *rib, struct rde_peer *peer, uint32_t path_id,
     struct bgpd_addr *prefix, int prefixlen)
 {
 	struct rib_entry	*re;
@@ -906,24 +913,61 @@ prefix_get(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
 }
 
 /*
- * lookup prefix in the peer prefix_index. Returns NULL if not found.
+ * Search for specified prefix in the peer prefix_index.
+ * Returns NULL if not found.
  */
 struct prefix *
-prefix_lookup(struct rde_peer *peer, struct bgpd_addr *prefix,
-    int prefixlen)
+prefix_adjout_get(struct rde_peer *peer, uint32_t path_id,
+    struct bgpd_addr *prefix, int prefixlen)
 {
 	struct prefix xp;
-	struct pt_entry	*pte;
 
 	memset(&xp, 0, sizeof(xp));
-	pte = pt_fill(prefix, prefixlen);
-	xp.pt = pte;
+	xp.pt = pt_fill(prefix, prefixlen);
+	xp.path_id_tx = path_id;
 
 	return RB_FIND(prefix_index, &peer->adj_rib_out, &xp);
 }
 
+/*
+ * Lookup a prefix without considering path_id in the peer prefix_index.
+ * Returns NULL if not found.
+ */
 struct prefix *
-prefix_match(struct rde_peer *peer, struct bgpd_addr *addr)
+prefix_adjout_lookup(struct rde_peer *peer, struct bgpd_addr *prefix,
+    int prefixlen)
+{
+	struct prefix xp, *np;
+
+	memset(&xp, 0, sizeof(xp));
+	xp.pt = pt_fill(prefix, prefixlen);
+
+	np = RB_NFIND(prefix_index, &peer->adj_rib_out, &xp);
+	if (np == NULL || pt_prefix_cmp(np->pt, xp.pt) != 0)
+		return NULL;
+	return np;
+}
+
+/*
+ * Return next prefix after a lookup that is actually an update.
+ */
+struct prefix *
+prefix_adjout_next(struct rde_peer *peer, struct prefix *p)
+{
+	struct prefix *np;
+
+	np = RB_NEXT(prefix_index, &peer->adj_rib_out, p);
+	if (np == NULL || np->pt != p->pt)
+		return NULL;
+	return np;
+}
+
+/*
+ * Lookup addr in the peer prefix_index. Returns first match.
+ * Returns NULL if not found.
+ */
+struct prefix *
+prefix_adjout_match(struct rde_peer *peer, struct bgpd_addr *addr)
 {
 	struct prefix *p;
 	int i;
@@ -932,7 +976,7 @@ prefix_match(struct rde_peer *peer, struct bgpd_addr *addr)
 	case AID_INET:
 	case AID_VPN_IPv4:
 		for (i = 32; i >= 0; i--) {
-			p = prefix_lookup(peer, addr, i);
+			p = prefix_adjout_lookup(peer, addr, i);
 			if (p != NULL)
 				return p;
 		}
@@ -940,7 +984,7 @@ prefix_match(struct rde_peer *peer, struct bgpd_addr *addr)
 	case AID_INET6:
 	case AID_VPN_IPv6:
 		for (i = 128; i >= 0; i--) {
-			p = prefix_lookup(peer, addr, i);
+			p = prefix_adjout_lookup(peer, addr, i);
 			if (p != NULL)
 				return p;
 		}
@@ -956,9 +1000,9 @@ prefix_match(struct rde_peer *peer, struct bgpd_addr *addr)
  * Return 1 if prefix was newly added, 0 if it was just changed.
  */
 int
-prefix_update(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
+prefix_update(struct rib *rib, struct rde_peer *peer, uint32_t path_id,
     struct filterstate *state, struct bgpd_addr *prefix, int prefixlen,
-    u_int8_t vstate)
+    uint8_t vstate)
 {
 	struct rde_aspath	*asp, *nasp = &state->aspath;
 	struct rde_community	*comm, *ncomm = &state->communities;
@@ -1009,9 +1053,9 @@ prefix_update(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
  */
 static int
 prefix_add(struct bgpd_addr *prefix, int prefixlen, struct rib *rib,
-    struct rde_peer *peer, u_int32_t path_id, struct rde_aspath *asp,
-    struct rde_community *comm, struct nexthop *nexthop, u_int8_t nhflags,
-    u_int8_t vstate)
+    struct rde_peer *peer, uint32_t path_id, struct rde_aspath *asp,
+    struct rde_community *comm, struct nexthop *nexthop, uint8_t nhflags,
+    uint8_t vstate)
 {
 	struct prefix		*p;
 	struct rib_entry	*re;
@@ -1021,7 +1065,14 @@ prefix_add(struct bgpd_addr *prefix, int prefixlen, struct rib *rib,
 		re = rib_add(rib, prefix, prefixlen);
 
 	p = prefix_alloc();
-	prefix_link(p, re, peer, path_id, asp, comm, nexthop, nhflags, vstate);
+	prefix_link(p, re, re->prefix, peer, path_id, asp, comm, nexthop,
+	    nhflags, vstate);
+
+	/* add possible pftable reference form aspath */
+	if (asp && asp->pftableid)
+		rde_pftable_add(asp->pftableid, p);
+	/* make route decision */
+	prefix_evaluate(re, p, NULL);
 	return (1);
 }
 
@@ -1031,7 +1082,7 @@ prefix_add(struct bgpd_addr *prefix, int prefixlen, struct rib *rib,
 static int
 prefix_move(struct prefix *p, struct rde_peer *peer,
     struct rde_aspath *asp, struct rde_community *comm,
-    struct nexthop *nexthop, u_int8_t nhflags, u_int8_t vstate)
+    struct nexthop *nexthop, uint8_t nhflags, uint8_t vstate)
 {
 	struct prefix		*np;
 
@@ -1043,18 +1094,8 @@ prefix_move(struct prefix *p, struct rde_peer *peer,
 
 	/* add new prefix node */
 	np = prefix_alloc();
-	/* add reference to new AS path and communities */
-	np->aspath = path_ref(asp);
-	np->communities = communities_ref(comm);
-	np->peer = peer;
-	np->entry.list.re = prefix_re(p);
-	np->pt = p->pt; /* skip refcnt update since ref is moved */
-	np->path_id = p->path_id;
-	np->validation_state = vstate;
-	np->nhflags = nhflags;
-	np->nexthop = nexthop_ref(nexthop);
-	nexthop_link(np);
-	np->lastchange = getmonotime();
+	prefix_link(np, prefix_re(p), p->pt, peer, p->path_id, asp, comm,
+	    nexthop, nhflags, vstate);
 
 	/* add possible pftable reference from new aspath */
 	if (asp && asp->pftableid)
@@ -1066,21 +1107,12 @@ prefix_move(struct prefix *p, struct rde_peer *peer,
 	 */
 	prefix_evaluate(prefix_re(np), np, p);
 
-	/* remove possible pftable reference from old path first */
+	/* remove possible pftable reference from old path */
 	if (p->aspath && p->aspath->pftableid)
 		rde_pftable_del(p->aspath->pftableid, p);
 
 	/* remove old prefix node */
-	nexthop_unlink(p);
-	nexthop_unref(p->nexthop);
-	communities_unref(p->communities);
-	path_unref(p->aspath);
-	p->communities = NULL;
-	p->nexthop = NULL;
-	p->aspath = NULL;
-	p->peer = NULL;
-	p->pt = NULL;
-	p->entry.list.re = NULL;
+	prefix_unlink(p);
 	prefix_free(p);
 
 	return (0);
@@ -1091,7 +1123,7 @@ prefix_move(struct prefix *p, struct rde_peer *peer,
  * or pt_entry -- become empty remove them too.
  */
 int
-prefix_withdraw(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
+prefix_withdraw(struct rib *rib, struct rde_peer *peer, uint32_t path_id,
     struct bgpd_addr *prefix, int prefixlen)
 {
 	struct prefix		*p;
@@ -1117,13 +1149,12 @@ prefix_withdraw(struct rib *rib, struct rde_peer *peer, u_int32_t path_id,
  * Insert an End-of-RIB marker into the update queue.
  */
 void
-prefix_add_eor(struct rde_peer *peer, u_int8_t aid)
+prefix_add_eor(struct rde_peer *peer, uint8_t aid)
 {
 	struct prefix *p;
 
 	p = prefix_alloc();
-	p->flags = PREFIX_FLAG_ADJOUT | PREFIX_FLAG_UPDATE;
-	p->eor = 1;
+	p->flags = PREFIX_FLAG_ADJOUT | PREFIX_FLAG_UPDATE | PREFIX_FLAG_EOR;
 	if (RB_INSERT(prefix_tree, &peer->updates[aid], p) != NULL)
 		/* no need to add if EoR marker already present */
 		prefix_free(p);
@@ -1133,70 +1164,63 @@ prefix_add_eor(struct rde_peer *peer, u_int8_t aid)
 /*
  * Put a prefix from the Adj-RIB-Out onto the update queue.
  */
-int
+void
 prefix_adjout_update(struct rde_peer *peer, struct filterstate *state,
-    struct bgpd_addr *prefix, int prefixlen, u_int8_t vstate)
+    struct bgpd_addr *prefix, int prefixlen, uint8_t vstate)
 {
-	struct prefix_tree *prefix_head = NULL;
 	struct rde_aspath *asp;
 	struct rde_community *comm;
 	struct prefix *p;
-	int created = 0;
 
-	if ((p = prefix_lookup(peer, prefix, prefixlen)) != NULL) {
-		if ((p->flags & PREFIX_FLAG_ADJOUT) == 0)
-			fatalx("%s: prefix without PREFIX_FLAG_ADJOUT hit",
-			    __func__);
-		/* prefix is already in the Adj-RIB-Out */
-		if (p->flags & PREFIX_FLAG_WITHDRAW) {
-			created = 1;	/* consider this a new entry */
-			peer->up_wcnt--;
-			prefix_head = &peer->withdraws[prefix->aid];
-			RB_REMOVE(prefix_tree, prefix_head, p);
-		} else if (p->flags & PREFIX_FLAG_DEAD) {
-			created = 1;	/* consider this a new entry */
-		} else {
-			if (prefix_nhflags(p) == state->nhflags &&
-			    prefix_nexthop(p) == state->nexthop &&
-			    communities_equal(&state->communities,
-			    prefix_communities(p)) &&
-			    path_compare(&state->aspath, prefix_aspath(p)) ==
-			    0) {
-				/* nothing changed */
-				p->validation_state = vstate;
-				p->lastchange = getmonotime();
-				p->flags &= ~PREFIX_FLAG_STALE;
-				return 0;
-			}
-
-			if (p->flags & PREFIX_FLAG_UPDATE) {
-				/* created = 0 so up_nlricnt is not increased */
-				prefix_head = &peer->updates[prefix->aid];
-				RB_REMOVE(prefix_tree, prefix_head, p);
-			}
-		}
-		/* unlink from aspath and remove nexthop ref */
-		nexthop_unref(p->nexthop);
-		communities_unref(p->communities);
-		path_unref(p->aspath);
-		p->flags &= ~PREFIX_FLAG_MASK;
-
-		/* peer and pt remain */
-	} else {
+	if ((p = prefix_adjout_get(peer, 0, prefix, prefixlen)) == NULL) {
 		p = prefix_alloc();
-		p->flags |= PREFIX_FLAG_ADJOUT;
-		created = 1;
+		/* initally mark DEAD so code below is skipped */
+		p->flags |= PREFIX_FLAG_ADJOUT | PREFIX_FLAG_DEAD;
 
 		p->pt = pt_get(prefix, prefixlen);
 		if (p->pt == NULL)
 			p->pt = pt_add(prefix, prefixlen);
 		pt_ref(p->pt);
 		p->peer = peer;
+		p->path_id_tx = 0 /* XXX force this for now */;
 
 		if (RB_INSERT(prefix_index, &peer->adj_rib_out, p) != NULL)
 			fatalx("%s: RB index invariant violated", __func__);
 	}
 
+	if ((p->flags & PREFIX_FLAG_ADJOUT) == 0)
+		fatalx("%s: prefix without PREFIX_FLAG_ADJOUT hit", __func__);
+	if ((p->flags & (PREFIX_FLAG_WITHDRAW | PREFIX_FLAG_DEAD)) == 0) {
+		if (prefix_nhflags(p) == state->nhflags &&
+		    prefix_nexthop(p) == state->nexthop &&
+		    communities_equal(&state->communities,
+		    prefix_communities(p)) &&
+		    path_compare(&state->aspath, prefix_aspath(p)) == 0) {
+			/* nothing changed */
+			p->validation_state = vstate;
+			p->lastchange = getmonotime();
+			p->flags &= ~PREFIX_FLAG_STALE;
+			return;
+		}
+
+		/* if pending update unhook it before it is unlinked */
+		if (p->flags & PREFIX_FLAG_UPDATE) {
+			RB_REMOVE(prefix_tree, &peer->updates[prefix->aid], p);
+			peer->up_nlricnt--;
+		}
+
+		/* unlink prefix so it can be relinked below */
+		prefix_unlink(p);
+		peer->prefix_out_cnt--;
+	}
+	if (p->flags & PREFIX_FLAG_WITHDRAW) {
+		RB_REMOVE(prefix_tree, &peer->withdraws[prefix->aid], p);
+		peer->up_wcnt--;
+	}
+
+	/* nothing needs to be done for PREFIX_FLAG_DEAD and STALE */
+	p->flags &= ~PREFIX_FLAG_MASK;
+
 	if ((asp = path_lookup(&state->aspath)) == NULL) {
 		/* Path not available, create and link a new one. */
 		asp = path_copy(path_get(), &state->aspath);
@@ -1208,36 +1232,26 @@ prefix_adjout_update(struct rde_peer *peer, struct filterstate *state,
 		comm = communities_link(&state->communities);
 	}
 
-	p->aspath = path_ref(asp);
-	p->communities = communities_ref(comm);
-	p->nexthop = nexthop_ref(state->nexthop);
-	p->nhflags = state->nhflags;
-
-	p->validation_state = vstate;
-	p->lastchange = getmonotime();
+	prefix_link(p, NULL, p->pt, peer, 0, asp, comm, state->nexthop,
+	    state->nhflags, vstate);
+	peer->prefix_out_cnt++;
 
 	if (p->flags & PREFIX_FLAG_MASK)
 		fatalx("%s: bad flags %x", __func__, p->flags);
 	p->flags |= PREFIX_FLAG_UPDATE;
 	if (RB_INSERT(prefix_tree, &peer->updates[prefix->aid], p) != NULL)
 		fatalx("%s: RB tree invariant violated", __func__);
-
-	return created;
+	peer->up_nlricnt++;
 }
 
 /*
  * Withdraw a prefix from the Adj-RIB-Out, this unlinks the aspath but leaves
  * the prefix in the RIB linked to the peer withdraw list.
  */
-int
-prefix_adjout_withdraw(struct rde_peer *peer, struct bgpd_addr *prefix,
-    int prefixlen)
+void
+prefix_adjout_withdraw(struct prefix *p)
 {
-	struct prefix *p;
-
-	p = prefix_lookup(peer, prefix, prefixlen);
-	if (p == NULL)		/* Got a dummy withdrawn request. */
-		return (0);
+	struct rde_peer *peer = prefix_peer(p);
 
 	if ((p->flags & PREFIX_FLAG_ADJOUT) == 0)
 		fatalx("%s: prefix without PREFIX_FLAG_ADJOUT hit", __func__);
@@ -1246,37 +1260,69 @@ prefix_adjout_withdraw(struct rde_peer *peer, struct bgpd_addr *prefix,
 	if (p->flags & PREFIX_FLAG_WITHDRAW) {
 		p->lastchange = getmonotime();
 		p->flags &= ~PREFIX_FLAG_STALE;
-		return (0);
+		return;
 	}
 	/* pending update just got withdrawn */
-	if (p->flags & PREFIX_FLAG_UPDATE)
+	if (p->flags & PREFIX_FLAG_UPDATE) {
 		RB_REMOVE(prefix_tree, &peer->updates[p->pt->aid], p);
+		peer->up_nlricnt--;
+	}
+	/* unlink prefix if it was linked (not a withdraw or dead) */
+	if ((p->flags & (PREFIX_FLAG_WITHDRAW | PREFIX_FLAG_DEAD)) == 0) {
+		prefix_unlink(p);
+		peer->prefix_out_cnt--;
+	}
+
 	/* nothing needs to be done for PREFIX_FLAG_DEAD and STALE */
 	p->flags &= ~PREFIX_FLAG_MASK;
-
-	/* remove nexthop ref ... */
-	nexthop_unref(p->nexthop);
-	p->nexthop = NULL;
-	p->nhflags = 0;
-
-	/* unlink from aspath ...*/
-	path_unref(p->aspath);
-	p->aspath = NULL;
-
-	/* ... communities ... */
-	communities_unref(p->communities);
-	p->communities = NULL;
-	/* and unlink from aspath */
-	path_unref(p->aspath);
-	p->aspath = NULL;
-	/* re already NULL */
-
 	p->lastchange = getmonotime();
 
 	p->flags |= PREFIX_FLAG_WITHDRAW;
-	if (RB_INSERT(prefix_tree, &peer->withdraws[prefix->aid], p) != NULL)
+	if (RB_INSERT(prefix_tree, &peer->withdraws[p->pt->aid], p) != NULL)
 		fatalx("%s: RB tree invariant violated", __func__);
-	return (1);
+	peer->up_wcnt++;
+}
+
+void
+prefix_adjout_destroy(struct prefix *p)
+{
+	struct rde_peer *peer = prefix_peer(p);
+
+	if ((p->flags & PREFIX_FLAG_ADJOUT) == 0)
+		fatalx("%s: prefix without PREFIX_FLAG_ADJOUT hit", __func__);
+
+	if (p->flags & PREFIX_FLAG_EOR) {
+		/* EOR marker is not linked in the index */
+		prefix_free(p);
+		return;
+	}
+
+	if (p->flags & PREFIX_FLAG_WITHDRAW) {
+		RB_REMOVE(prefix_tree, &peer->withdraws[p->pt->aid], p);
+		peer->up_wcnt--;
+	}
+	if (p->flags & PREFIX_FLAG_UPDATE) {
+		RB_REMOVE(prefix_tree, &peer->updates[p->pt->aid], p);
+		peer->up_nlricnt--;
+	}
+	/* unlink prefix if it was linked (not a withdraw or dead) */
+	if ((p->flags & (PREFIX_FLAG_WITHDRAW | PREFIX_FLAG_DEAD)) == 0) {
+		prefix_unlink(p);
+		peer->prefix_out_cnt--;
+	}
+
+	/* nothing needs to be done for PREFIX_FLAG_DEAD and STALE */
+	p->flags &= ~PREFIX_FLAG_MASK;
+
+	if (prefix_is_locked(p)) {
+		/* mark prefix dead but leave it for prefix_restart */
+		p->flags |= PREFIX_FLAG_DEAD;
+	} else {
+		RB_REMOVE(prefix_index, &peer->adj_rib_out, p);
+		/* remove the last prefix reference before free */
+		pt_unref(p->pt);
+		prefix_free(p);
+	}
 }
 
 static struct prefix *
@@ -1297,52 +1343,6 @@ prefix_restart(struct rib_context *ctx)
 	return p;
 }
 
-void
-prefix_adjout_destroy(struct prefix *p)
-{
-	struct rde_peer *peer = prefix_peer(p);
-
-	if ((p->flags & PREFIX_FLAG_ADJOUT) == 0)
-		fatalx("%s: prefix without PREFIX_FLAG_ADJOUT hit", __func__);
-
-	if (p->eor) {
-		/* EOR marker is not linked in the index */
-		prefix_free(p);
-		return;
-	}
-
-	if (p->flags & PREFIX_FLAG_WITHDRAW)
-		RB_REMOVE(prefix_tree, &peer->withdraws[p->pt->aid], p);
-	else if (p->flags & PREFIX_FLAG_UPDATE)
-		RB_REMOVE(prefix_tree, &peer->updates[p->pt->aid], p);
-	/* nothing needs to be done for PREFIX_FLAG_DEAD and STALE */
-	p->flags &= ~PREFIX_FLAG_MASK;
-
-
-	if (prefix_is_locked(p)) {
-		/* remove nexthop ref ... */
-		nexthop_unref(p->nexthop);
-		p->nexthop = NULL;
-		/* ... communities ... */
-		communities_unref(p->communities);
-		p->communities = NULL;
-		/* and unlink from aspath */
-		path_unref(p->aspath);
-		p->aspath = NULL;
-		p->nhflags = 0;
-		/* re already NULL */
-
-		/* finally mark prefix dead */
-		p->flags |= PREFIX_FLAG_DEAD;
-		return;
-	}
-
-	RB_REMOVE(prefix_index, &peer->adj_rib_out, p);
-
-	prefix_unlink(p);
-	prefix_free(p);
-}
-
 static void
 prefix_dump_r(struct rib_context *ctx)
 {
@@ -1382,9 +1382,9 @@ done:
 }
 
 int
-prefix_dump_new(struct rde_peer *peer, u_int8_t aid, unsigned int count,
+prefix_dump_new(struct rde_peer *peer, uint8_t aid, unsigned int count,
     void *arg, void (*upcall)(struct prefix *, void *),
-    void (*done)(void *, u_int8_t), int (*throttle)(void *))
+    void (*done)(void *, uint8_t), int (*throttle)(void *))
 {
 	struct rib_context *ctx;
 
@@ -1409,7 +1409,7 @@ prefix_dump_new(struct rde_peer *peer, u_int8_t aid, unsigned int count,
 
 /* dump a prefix into specified buffer */
 int
-prefix_write(u_char *buf, int len, struct bgpd_addr *prefix, u_int8_t plen,
+prefix_write(u_char *buf, int len, struct bgpd_addr *prefix, uint8_t plen,
     int withdraw)
 {
 	int	totlen, psize;
@@ -1461,7 +1461,7 @@ prefix_write(u_char *buf, int len, struct bgpd_addr *prefix, u_int8_t plen,
 }
 
 int
-prefix_writebuf(struct ibuf *buf, struct bgpd_addr *prefix, u_int8_t plen)
+prefix_writebuf(struct ibuf *buf, struct bgpd_addr *prefix, uint8_t plen)
 {
 	int	 totlen;
 	void	*bptr;
@@ -1492,11 +1492,11 @@ prefix_writebuf(struct ibuf *buf, struct bgpd_addr *prefix, u_int8_t plen)
  * belonging to the peer peer. Returns NULL if no match found.
  */
 struct prefix *
-prefix_bypeer(struct rib_entry *re, struct rde_peer *peer, u_int32_t path_id)
+prefix_bypeer(struct rib_entry *re, struct rde_peer *peer, uint32_t path_id)
 {
 	struct prefix	*p;
 
-	LIST_FOREACH(p, &re->prefix_h, entry.list.rib)
+	TAILQ_FOREACH(p, &re->prefix_h, entry.list.rib)
 		if (prefix_peer(p) == peer && p->path_id == path_id)
 			return (p);
 	return (NULL);
@@ -1523,7 +1523,7 @@ prefix_evaluate_all(struct prefix *p, enum nexthop_state state,
 		 */
 		if (state == NEXTHOP_REACH) {
 			if ((re_rib(re)->flags & F_RIB_NOFIB) == 0 &&
-			    p == re->active)
+			    p == prefix_best(re))
 				rde_send_kroute(re_rib(re), p, NULL);
 		}
 		return;
@@ -1548,31 +1548,23 @@ prefix_destroy(struct prefix *p)
  * Link a prefix into the different parent objects.
  */
 static void
-prefix_link(struct prefix *p, struct rib_entry *re, struct rde_peer *peer,
-    u_int32_t path_id, struct rde_aspath *asp, struct rde_community *comm,
-    struct nexthop *nexthop, u_int8_t nhflags, u_int8_t vstate)
+prefix_link(struct prefix *p, struct rib_entry *re, struct pt_entry *pt,
+    struct rde_peer *peer, uint32_t path_id, struct rde_aspath *asp,
+    struct rde_community *comm, struct nexthop *nexthop, uint8_t nhflags,
+    uint8_t vstate)
 {
-	if (p->flags & PREFIX_FLAG_ADJOUT)
-		fatalx("%s: prefix with PREFIX_FLAG_ADJOUT hit", __func__);
-
-	p->entry.list.re = re;
+	if (re)
+		p->entry.list.re = re;
 	p->aspath = path_ref(asp);
 	p->communities = communities_ref(comm);
 	p->peer = peer;
-	p->pt = pt_ref(re->prefix);
+	p->pt = pt_ref(pt);
 	p->path_id = path_id;
 	p->validation_state = vstate;
 	p->nhflags = nhflags;
 	p->nexthop = nexthop_ref(nexthop);
 	nexthop_link(p);
 	p->lastchange = getmonotime();
-
-	/* add possible pftable reference from aspath */
-	if (asp && asp->pftableid)
-		rde_pftable_add(asp->pftableid, p);
-
-	/* make route decision */
-	prefix_evaluate(re, p, NULL);
 }
 
 /*
@@ -1584,24 +1576,22 @@ prefix_unlink(struct prefix *p)
 	struct rib_entry	*re = prefix_re(p);
 
 	/* destroy all references to other objects */
+	/* remove nexthop ref ... */
 	nexthop_unlink(p);
 	nexthop_unref(p->nexthop);
-	communities_unref(p->communities);
-	path_unref(p->aspath);
-	pt_unref(p->pt);
-	p->communities = NULL;
 	p->nexthop = NULL;
+	p->nhflags = 0;
+	/* ... communities ... */
+	communities_unref(p->communities);
+	p->communities = NULL;
+	/* and unlink from aspath */
+	path_unref(p->aspath);
 	p->aspath = NULL;
-	p->peer = NULL;
-	p->pt = NULL;
 
 	if (re && rib_empty(re))
 		rib_remove(re);
 
-	/*
-	 * It's the caller's duty to do accounting and remove empty aspath
-	 * structures. Also freeing the unlinked prefix is the caller's duty.
-	 */
+	pt_unref(p->pt);
 }
 
 /* alloc and zero new entry. May not fail. */
@@ -1642,7 +1632,7 @@ struct nexthop		*nexthop_lookup(struct bgpd_addr *);
  */
 struct nexthop_table {
 	LIST_HEAD(nexthop_head, nexthop)	*nexthop_hashtbl;
-	u_int32_t				 nexthop_hashmask;
+	uint32_t				 nexthop_hashmask;
 } nexthoptable;
 
 SIPHASH_KEY nexthoptablekey;
@@ -1650,9 +1640,9 @@ SIPHASH_KEY nexthoptablekey;
 TAILQ_HEAD(nexthop_queue, nexthop)	nexthop_runners;
 
 void
-nexthop_init(u_int32_t hashsize)
+nexthop_init(uint32_t hashsize)
 {
-	u_int32_t	 hs, i;
+	uint32_t	 hs, i;
 
 	for (hs = 1; hs < hashsize; hs <<= 1)
 		;
@@ -1671,7 +1661,7 @@ nexthop_init(u_int32_t hashsize)
 void
 nexthop_shutdown(void)
 {
-	u_int32_t		 i;
+	uint32_t		 i;
 	struct nexthop		*nh, *nnh;
 
 	for (i = 0; i <= nexthoptable.nexthop_hashmask; i++) {
@@ -1703,7 +1693,7 @@ nexthop_runner(void)
 {
 	struct nexthop *nh;
 	struct prefix *p;
-	u_int32_t j;
+	uint32_t j;
 
 	nh = TAILQ_FIRST(&nexthop_runners);
 	if (nh == NULL)
@@ -1781,8 +1771,8 @@ nexthop_update(struct kroute_nexthop *msg)
 }
 
 void
-nexthop_modify(struct nexthop *setnh, enum action_types type, u_int8_t aid,
-    struct nexthop **nexthop, u_int8_t *flags)
+nexthop_modify(struct nexthop *setnh, enum action_types type, uint8_t aid,
+    struct nexthop **nexthop, uint8_t *flags)
 {
 	switch (type) {
 	case ACTION_SET_NEXTHOP_REJECT:
@@ -1818,6 +1808,8 @@ nexthop_link(struct prefix *p)
 {
 	if (p->nexthop == NULL)
 		return;
+	if (p->flags & PREFIX_FLAG_ADJOUT)
+		return;
 
 	/* no need to link prefixes in RIBs that have no decision process */
 	if (re_rib(prefix_re(p))->flags & F_RIB_NOEVALUATE)
@@ -1953,7 +1945,7 @@ nexthop_lookup(struct bgpd_addr *nexthop)
 struct nexthop_head *
 nexthop_hash(struct bgpd_addr *nexthop)
 {
-	u_int32_t	 h = 0;
+	uint32_t	 h = 0;
 
 	switch (nexthop->aid) {
 	case AID_INET:
