@@ -1,4 +1,4 @@
-/*	$OpenBSD: rde_update.c,v 1.131 2021/08/09 08:15:35 claudio Exp $ */
+/*	$OpenBSD: rde_update.c,v 1.139 2022/03/30 16:06:32 tb Exp $ */
 
 /*
  * Copyright (c) 2004 Claudio Jeker <claudio@openbsd.org>
@@ -45,7 +45,7 @@ static struct community	comm_no_expsubconfed = {
 	.data2 = COMMUNITY_NO_EXPSUBCONFED
 };
 
-static void up_prep_adjout(struct rde_peer *, struct filterstate *, u_int8_t);
+static void up_prep_adjout(struct rde_peer *, struct filterstate *, uint8_t);
 
 static int
 up_test_update(struct rde_peer *peer, struct prefix *p)
@@ -102,6 +102,7 @@ up_generate_updates(struct filter_head *rules, struct rde_peer *peer,
 {
 	struct filterstate	state;
 	struct bgpd_addr	addr;
+	struct prefix		*p;
 	int			need_withdraw;
 	uint8_t			prefixlen;
 
@@ -116,14 +117,7 @@ up_generate_updates(struct filter_head *rules, struct rde_peer *peer,
 		prefixlen = new->pt->prefixlen;
 	}
 
-again:
-	if (new == NULL) {
-		/* withdraw prefix */
-		if (prefix_adjout_withdraw(peer, &addr, prefixlen) == 1) {
-			peer->prefix_out_cnt--;
-			peer->up_wcnt++;
-		}
-	} else {
+	while (new != NULL) {
 		need_withdraw = 0;
 		/*
 		 * up_test_update() needs to run before the output filters
@@ -143,10 +137,8 @@ again:
 		 * skip the filters.
 		 */
 		if (need_withdraw &&
-		    !(peer->flags & PEERFLAG_EVALUATE_ALL)) {
-			new = NULL;
-			goto again;
-		}
+		    !(peer->flags & PEERFLAG_EVALUATE_ALL))
+			break;
 
 		rde_filterstate_prep(&state, prefix_aspath(new),
 		    prefix_communities(new), prefix_nexthop(new),
@@ -154,29 +146,23 @@ again:
 		if (rde_filter(rules, peer, prefix_peer(new), &addr,
 		    prefixlen, prefix_vstate(new), &state) == ACTION_DENY) {
 			rde_filterstate_clean(&state);
-			if (peer->flags & PEERFLAG_EVALUATE_ALL)
-				new = LIST_NEXT(new, entry.list.rib);
-			else
-				new = NULL;
-			if (new != NULL && !prefix_eligible(new))
-				new = NULL;
-			goto again;
+			if (peer->flags & PEERFLAG_EVALUATE_ALL) {
+				new = TAILQ_NEXT(new, entry.list.rib);
+				if (new != NULL && prefix_eligible(new))
+					continue;
+			}
+			break;
 		}
 
-		if (need_withdraw) {
-			new = NULL;
-			goto again;
-		}
+		/* check if this was actually a withdraw */
+		if (need_withdraw)
+			break;
+
+		/* from here on we know this is an update */
 
 		up_prep_adjout(peer, &state, addr.aid);
-
-		/* only send update if path changed */
-		if (prefix_adjout_update(peer, &state, &addr,
-		    new->pt->prefixlen, prefix_vstate(new)) == 1) {
-			peer->prefix_out_cnt++;
-			peer->up_nlricnt++;
-		}
-
+		prefix_adjout_update(peer, &state, &addr,
+		    new->pt->prefixlen, prefix_vstate(new));
 		rde_filterstate_clean(&state);
 
 		/* max prefix checker outbound */
@@ -188,7 +174,13 @@ again:
 			rde_update_err(peer, ERR_CEASE,
 			    ERR_CEASE_MAX_SENT_PREFIX, NULL, 0);
 		}
+
+		return;
 	}
+
+	/* withdraw prefix */
+	if ((p = prefix_adjout_get(peer, 0, &addr, prefixlen)) != NULL)
+		prefix_adjout_withdraw(p);
 }
 
 struct rib_entry *rib_add(struct rib *, struct bgpd_addr *, int);
@@ -198,7 +190,7 @@ int rib_empty(struct rib_entry *);
 /* send a default route to the specified peer */
 void
 up_generate_default(struct filter_head *rules, struct rde_peer *peer,
-    u_int8_t aid)
+    uint8_t aid)
 {
 	extern struct rde_peer	*peerself;
 	struct filterstate	 state;
@@ -230,13 +222,7 @@ up_generate_default(struct filter_head *rules, struct rde_peer *peer,
 	}
 
 	up_prep_adjout(peer, &state, addr.aid);
-
-	if (prefix_adjout_update(peer, &state, &addr, 0, ROA_NOTFOUND) == 1) {
-		peer->prefix_out_cnt++;
-		peer->up_nlricnt++;
-	}
-
-	/* no longer needed */
+	prefix_adjout_update(peer, &state, &addr, 0, ROA_NOTFOUND);
 	rde_filterstate_clean(&state);
 
 	/* max prefix checker outbound */
@@ -251,7 +237,7 @@ up_generate_default(struct filter_head *rules, struct rde_peer *peer,
 }
 
 static struct bgpd_addr *
-up_get_nexthop(struct rde_peer *peer, struct filterstate *state, u_int8_t aid)
+up_get_nexthop(struct rde_peer *peer, struct filterstate *state, uint8_t aid)
 {
 	struct bgpd_addr *peer_local;
 
@@ -331,16 +317,16 @@ up_get_nexthop(struct rde_peer *peer, struct filterstate *state, u_int8_t aid)
 }
 
 static void
-up_prep_adjout(struct rde_peer *peer, struct filterstate *state, u_int8_t aid)
+up_prep_adjout(struct rde_peer *peer, struct filterstate *state, uint8_t aid)
 {
 	struct bgpd_addr *nexthop;
 	struct nexthop *nh;
 	u_char *np;
-	u_int16_t nl;
+	uint16_t nl;
 
 	/* prepend local AS number for eBGP sessions. */
 	if (peer->conf.ebgp && (peer->flags & PEERFLAG_TRANS_AS) == 0) {
-		u_int32_t prep_as = peer->conf.local_as;
+		uint32_t prep_as = peer->conf.local_as;
 		np = aspath_prepend(state->aspath.aspath, prep_as, 1, &nl);
 		aspath_put(state->aspath.aspath);
 		state->aspath.aspath = aspath_get(np, nl);
@@ -358,17 +344,17 @@ up_prep_adjout(struct rde_peer *peer, struct filterstate *state, u_int8_t aid)
 
 static int
 up_generate_attr(u_char *buf, int len, struct rde_peer *peer,
-    struct filterstate *state, u_int8_t aid)
+    struct filterstate *state, uint8_t aid)
 {
 	struct rde_aspath *asp = &state->aspath;
 	struct rde_community *comm = &state->communities;
 	struct attr	*oa = NULL, *newaggr = NULL;
 	u_char		*pdata;
-	u_int32_t	 tmp32;
+	uint32_t	 tmp32;
 	struct bgpd_addr *nexthop;
 	int		 flags, r, neednewpath = 0;
-	u_int16_t	 wlen = 0, plen;
-	u_int8_t	 oalen = 0, type;
+	uint16_t	 wlen = 0, plen;
+	uint8_t		 oalen = 0, type;
 
 	if (asp->others_len > 0)
 		oa = asp->others[oalen++];
@@ -521,8 +507,8 @@ up_generate_attr(u_char *buf, int len, struct rde_peer *peer,
 				break;
 			if (!peer_has_as4byte(peer)) {
 				/* need to deflate the aggregator */
-				u_int8_t	t[6];
-				u_int16_t	tas;
+				uint8_t	t[6];
+				uint16_t	tas;
 
 				if ((!(oa->flags & ATTR_TRANSITIVE)) &&
 				    peer->conf.ebgp) {
@@ -594,18 +580,18 @@ done:
  * tree and return 1.
  */
 int
-up_is_eor(struct rde_peer *peer, u_int8_t aid)
+up_is_eor(struct rde_peer *peer, uint8_t aid)
 {
 	struct prefix *p;
 
 	p = RB_MIN(prefix_tree, &peer->updates[aid]);
-	if (p != NULL && p->eor) {
+	if (p != NULL && (p->flags & PREFIX_FLAG_EOR)) {
 		/*
 		 * Need to remove eor from update tree because
 		 * prefix_adjout_destroy() can't handle that.
 		 */
 		RB_REMOVE(prefix_tree, &peer->updates[aid], p);
-		p->flags &= ~PREFIX_FLAG_MASK;
+		p->flags &= ~PREFIX_FLAG_UPDATE;
 		prefix_adjout_destroy(p);
 		return 1;
 	}
@@ -625,15 +611,14 @@ up_dump_prefix(u_char *buf, int len, struct prefix_tree *prefix_head,
 {
 	struct prefix	*p, *np;
 	struct bgpd_addr addr;
-	u_int32_t	 pathid;
+	uint32_t	 pathid;
 	int		 r, wpos = 0, done = 0;
 
 	RB_FOREACH_SAFE(p, prefix_tree, prefix_head, np) {
 		if (peer_has_add_path(peer, p->pt->aid, CAPA_AP_SEND)) {
 			if (len <= wpos + (int)sizeof(pathid))
 				break;
-			/* XXX add-path send side */
-			pathid = 0;
+			pathid = htonl(p->path_id_tx);
 			memcpy(buf + wpos, &pathid, sizeof(pathid));
 			wpos += sizeof(pathid);
 		}
@@ -649,20 +634,18 @@ up_dump_prefix(u_char *buf, int len, struct prefix_tree *prefix_head,
 		    np->communities != p->communities ||
 		    np->nexthop != p->nexthop ||
 		    np->nhflags != p->nhflags ||
-		    np->eor)
+		    (np->flags & PREFIX_FLAG_EOR))
 			done = 1;
 
-		/* prefix sent, remove from list and clear flag */
-		RB_REMOVE(prefix_tree, prefix_head, p);
-		p->flags &= ~PREFIX_FLAG_MASK;
 
 		if (withdraw) {
 			/* prefix no longer needed, remove it */
 			prefix_adjout_destroy(p);
-			peer->up_wcnt--;
 			peer->prefix_sent_withdraw++;
 		} else {
 			/* prefix still in Adj-RIB-Out, keep it */
+			RB_REMOVE(prefix_tree, prefix_head, p);
+			p->flags &= ~PREFIX_FLAG_UPDATE;
 			peer->up_nlricnt--;
 			peer->prefix_sent_update++;
 		}
@@ -673,9 +656,9 @@ up_dump_prefix(u_char *buf, int len, struct prefix_tree *prefix_head,
 }
 
 int
-up_dump_withdraws(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
+up_dump_withdraws(u_char *buf, int len, struct rde_peer *peer, uint8_t aid)
 {
-	u_int16_t wpos, wd_len;
+	uint16_t wpos, wd_len;
 	int r;
 
 	if (len < MIN_UPDATE_LEN)
@@ -692,11 +675,11 @@ up_dump_withdraws(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
 }
 
 int
-up_dump_mp_unreach(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
+up_dump_mp_unreach(u_char *buf, int len, struct rde_peer *peer, uint8_t aid)
 {
 	u_char		*attrbuf;
 	int		 wpos, r;
-	u_int16_t	 attr_len, tmp;
+	uint16_t	 attr_len, tmp;
 
 	if (len < MIN_UPDATE_LEN || RB_EMPTY(&peer->withdraws[aid]))
 		return (-1);
@@ -714,7 +697,7 @@ up_dump_mp_unreach(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
 	if (aid2afi(aid, &tmp, buf + wpos + 2))
 		fatalx("up_dump_mp_unreach: bad AID");
 	tmp = htons(tmp);
-	memcpy(buf + wpos, &tmp, sizeof(u_int16_t));
+	memcpy(buf + wpos, &tmp, sizeof(uint16_t));
 	wpos += 3;
 
 	r = up_dump_prefix(buf + wpos, len - wpos, &peer->withdraws[aid],
@@ -729,7 +712,7 @@ up_dump_mp_unreach(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
 	memcpy(attrbuf + 2, &attr_len, sizeof(attr_len));
 
 	/* write length fields */
-	bzero(buf, sizeof(u_int16_t));	/* withdrawn routes len */
+	bzero(buf, sizeof(uint16_t));	/* withdrawn routes len */
 	attr_len = htons(wpos - 4);
 	memcpy(buf + 2, &attr_len, sizeof(attr_len));
 
@@ -742,7 +725,7 @@ up_dump_attrnlri(u_char *buf, int len, struct rde_peer *peer)
 	struct filterstate	 state;
 	struct prefix		*p;
 	int			 r, wpos;
-	u_int16_t		 attr_len;
+	uint16_t		 attr_len;
 
 	if (len < 2)
 		fatalx("up_dump_attrnlri: buffer way too small");
@@ -786,12 +769,12 @@ done:
 
 static int
 up_generate_mp_reach(u_char *buf, int len, struct rde_peer *peer,
-    struct filterstate *state, u_int8_t aid)
+    struct filterstate *state, uint8_t aid)
 {
 	struct bgpd_addr	*nexthop;
 	u_char			*attrbuf;
 	int			 r, wpos, attrlen;
-	u_int16_t		 tmp;
+	uint16_t		 tmp;
 
 	if (len < 4)
 		return (-1);
@@ -828,8 +811,8 @@ up_generate_mp_reach(u_char *buf, int len, struct rde_peer *peer,
 			fatalx("up_generate_mp_reachi: bad AID");
 		tmp = htons(tmp);
 		memcpy(attrbuf, &tmp, sizeof(tmp));
-		attrbuf[3] = sizeof(u_int64_t) + sizeof(struct in_addr);
-		bzero(attrbuf + 4, sizeof(u_int64_t));
+		attrbuf[3] = sizeof(uint64_t) + sizeof(struct in_addr);
+		bzero(attrbuf + 4, sizeof(uint64_t));
 		attrbuf[16] = 0; /* Reserved must be 0 */
 
 		/* write nexthop */
@@ -846,8 +829,8 @@ up_generate_mp_reach(u_char *buf, int len, struct rde_peer *peer,
 			fatalx("up_generate_mp_reachi: bad AID");
 		tmp = htons(tmp);
 		memcpy(attrbuf, &tmp, sizeof(tmp));
-		attrbuf[3] = sizeof(u_int64_t) + sizeof(struct in6_addr);
-		bzero(attrbuf + 4, sizeof(u_int64_t));
+		attrbuf[3] = sizeof(uint64_t) + sizeof(struct in6_addr);
+		bzero(attrbuf + 4, sizeof(uint64_t));
 		attrbuf[28] = 0; /* Reserved must be 0 */
 
 		/* write nexthop */
@@ -875,12 +858,12 @@ up_generate_mp_reach(u_char *buf, int len, struct rde_peer *peer,
 }
 
 int
-up_dump_mp_reach(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
+up_dump_mp_reach(u_char *buf, int len, struct rde_peer *peer, uint8_t aid)
 {
 	struct filterstate	 state;
 	struct prefix		*p;
 	int			r, wpos;
-	u_int16_t		attr_len;
+	uint16_t		attr_len;
 
 	if (len < MIN_UPDATE_LEN)
 		return 0;
@@ -911,7 +894,7 @@ up_dump_mp_reach(u_char *buf, int len, struct rde_peer *peer, u_int8_t aid)
 	wpos += r;
 
 	/* write length fields */
-	bzero(buf, sizeof(u_int16_t));	/* withdrawn routes len */
+	bzero(buf, sizeof(uint16_t));	/* withdrawn routes len */
 	attr_len = htons(wpos - 4);
 	memcpy(buf + 2, &attr_len, sizeof(attr_len));
 
